#!/usr/bin/env python
#******************************************************************************
# 
#  Project:  Vertical Datum
#  Purpose:  Translate EGM96 .DAC file into gtx format.
#  Author:   Frank Warmerdam, warmerdam@pobox.com
# 
#******************************************************************************
#  Copyright (c) 2010, Frank Warmerdam
# 
#  Permission is hereby granted, free of charge, to any person obtaining a
#  copy of this software and associated documentation files (the "Software"),
#  to deal in the Software without restriction, including without limitation
#  the rights to use, copy, modify, merge, publish, distribute, sublicense,
#  and/or sell copies of the Software, and to permit persons to whom the
#  Software is furnished to do so, subject to the following conditions:
# 
#  The above copyright notice and this permission notice shall be included
#  in all copies or substantial portions of the Software.
# 
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
#  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
#  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#******************************************************************************

import sys
import string
from osgeo import osr
from osgeo import gdal

# =============================================================================
def Usage():

    print('Usage: egm96togtx.py')
    print('')
    print('  assumes WW15MGH.DAC in local directory, writes egm96_15.gtx')
    sys.exit(1)

# =============================================================================

if __name__ == '__main__':

    argv = gdal.GeneralCmdLineProcessor( sys.argv )
    if argv is None:
        sys.exit( 0 )
        
    if len(argv) != 1:
        Usage()
        
    vrt = """<VRTDataset rasterXSize="1440" rasterYSize="721">
  <VRTRasterBand dataType="Int16" band="1" subClass="VRTRawRasterBand">
    <SourceFilename>WW15MGH.DAC</SourceFilename>
    <ImageOffset>0</ImageOffset>
    <PixelOffset>2</PixelOffset>
    <LineOffset>2880</LineOffset>
    <ByteOrder>MSB</ByteOrder>
  </VRTRasterBand>
</VRTDataset>"""

    ds_vrt = gdal.Open(vrt)
    egm_cm = ds_vrt.GetRasterBand(1).ReadAsArray()
    ds_vrt = None

    # Scale from cm to meters.
    egm_m = egm_cm * 0.01

    drv = gdal.GetDriverByName( 'GTX' )
    ds_gtx = drv.Create( 'egm96_15.gtx', 1440, 721, 1, gdal.GDT_Float32 )
    ds_gtx.SetGeoTransform( (-180.25,0.25,0,90.125,0,-0.25) )

    east = egm_m[:,:720] * 1.0
    west = egm_m[:,720:] * 1.0

    ds_gtx.GetRasterBand(1).WriteArray( east, 720, 0 )
    ds_gtx.GetRasterBand(1).WriteArray( west, 0, 0 )
    
    ds_gtx = None
